@@ -12,7 +12,20 @@ class PyMinio:
     def set_bucket(self, bucket):
         self.bucket = bucket
 
-    def download(self, object_name:str, local_name:str) -> bool:
+    def _trim_bucket(self, object_name:str, *, trim:bool) -> str:
+        if object_name[0]=='/':
+            object_name = object_name[1:]
+            
+        # 去掉前面的桶的名字
+        if trim==True:
+            arr = ticket.split('/')[1:]
+            object_name = os.path.join(*arr)
+
+        return object_name
+
+    def download(self, object_name:str, local_name:str, *, trim:bool=False) -> bool:
+        object_name = self._trim_bucket(object_name, trim=trim)
+
         if self.exists(object_name):
             self.client.fget_object(self.bucket, object_name, local_name)
             return True
@@ -30,7 +43,9 @@ class PyMinio:
         )
         return True
 
-    def exists(self, object_name:str) -> bool:
+    def exists(self, object_name:str, *, trim:bool=False) -> bool:
+        object_name = self._trim_bucket(object_name, trim=trim)
+
         try:
             response = self.client.get_object(self.bucket, object_name)
             response.close()
@@ -40,7 +55,8 @@ class PyMinio:
             return False
 
     # 删除对象
-    def remove_file(self, object_name:str) -> bool:
+    def remove_file(self, object_name:str, *, trim:bool=False) -> bool:
+        object_name = self._trim_bucket(object_name, trim=trim)
         try:
             self.client.remove_object(self.bucket, object_name)
             #print("Sussess")
